==> glassfish_1.0.0.orig.tar.gz: glassfish/tools/src/java/com/sun/enterprise/tools/common/dd/webservice/ResourceRefType.java <==
/**
 *	This generated bean class ResourceRefType matches the schema element resource-refType
 *
 *	===============================================================
 *	
 *		
 *	
 *		  The resource-refType contains a declaration of a
 *		  Deployment Component's reference to an external resource. It
 *		  consists of an optional description, the resource manager
 *		  connection factory reference name, the indication of the
 *		  resource manager connection factory type expected by the
 *		  Deployment Component code, the type of authentication
 *		  (Application or Container), and an optional specification of
 *		  the shareability of connections obtained from the resource
 *		  (Shareable or Unshareable).
 *	
 *		  Example:
 *	
 *		  <resource-ref>
 *		      <res-ref-name>jdbc/EmployeeAppDB</res-ref-name>
 *		      <res-type>javax.sql.DataSource</res-type>
 *		      <res-auth>Container</res-auth>
 *		      <res-sharing-scope>Shareable</res-sharing-scope>
 *		  </resource-ref>
 *	
 *		  
 *	      
 *	===============================================================
 *	Generated on Fri Apr 22 15:42:51 PDT 2005
 */

package com.sun.enterprise.tools.common.dd.webservice;

import org.w3c.dom.*;
import org.netbeans.modules.schema2beans.*;
import java.beans.*;
import java.util.*;

// BEGIN_NOI18N

public class ResourceRefType extends org.netbeans.modules.schema2beans.BaseBean
{

	static Vector comparators = new Vector();

	static public final String DESCRIPTION = "Description";	// NOI18N
	static public final String RES_REF_NAME = "ResRefName";	// NOI18N
	static public final String RES_TYPE = "ResType";	// NOI18N
	static public final String RES_AUTH = "ResAuth";	// NOI18N
	static public final String RES_SHARING_SCOPE = "ResSharingScope";	// NOI18N

	public ResourceRefType() {
		this(Common.USE_DEFAULT_VALUES);
	}

	public ResourceRefType(int options)
	{
		super(comparators, new org.netbeans.modules.schema2beans.Version(1, 2, 0));
		// Properties (see root bean comments for the bean graph)
		this.createProperty("description", 	// NOI18N
			DESCRIPTION, 
			Common.TYPE_0_N | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.createAttribute(DESCRIPTION, "id", "Id", 
						AttrProp.CDATA | AttrProp.IMPLIED,
						null, null);
		this.createAttribute(DESCRIPTION, "xml:lang", "XmlLang", 
						AttrProp.CDATA | AttrProp.IMPLIED,
						null, null);
		this.createProperty("res-ref-name", 	// NOI18N
			RES_REF_NAME, 
			Common.TYPE_1 | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.createProperty("res-type", 	// NOI18N
			RES_TYPE, 
			Common.TYPE_1 | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.createProperty("res-auth", 	// NOI18N
			RES_AUTH, 
			Common.TYPE_1 | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.createProperty("res-sharing-scope", 	// NOI18N
			RES_SHARING_SCOPE, 
			Common.TYPE_0_1 | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.initialize(options);
	}

	// Setting the default values of the properties
	void initialize(int options)
	{

	}

	// This attribute is an array, possibly empty
	public void setDescription(int index, java.lang.String value) {
		this.setValue(DESCRIPTION, index, value);
	}

	//
	public java.lang.String getDescription(int index) {
		return (java.lang.String)this.getValue(DESCRIPTION, index);
	}

	// This attribute is an array, possibly empty
	public void setDescription(java.lang.String[] value) {
		this.setValue(DESCRIPTION, value);
	}

	//
	public java.lang.String[] getDescription() {
		return (java.lang.String[])this.getValues(DESCRIPTION);
	}

	// Return the number of properties
	public int sizeDescription() {
		return this.size(DESCRIPTION);
	}

	// Add a new element returning its index in the list
	public int addDescription(java.lang.String value) {
		return this.addValue(DESCRIPTION, value);
	}

	//
	// Remove an element using its reference
	// Returns the index the element had in the list
	//
	public int removeDescription(java.lang.String value) {
		return this.removeValue(DESCRIPTION, value);
	}

	// This attribute is mandatory
	public void setResRefName(java.lang.String value) {
		this.setValue(RES_REF_NAME, value);
	}

	//
	public java.lang.String getResRefName() {
		return (java.lang.String)this.getValue(RES_REF_NAME);
	}

	// This attribute is mandatory
	public void setResType(java.lang.String value) {
		this.setValue(RES_TYPE, value);
	}

	//
	public java.lang.String getResType() {
		return (java.lang.String)this.getValue(RES_TYPE);
	}

	// This attribute is mandatory
	public void setResAuth(java.lang.String value) {
		this.setValue(RES_AUTH, value);
	}

	//
	public java.lang.String getResAuth() {
		return (java.lang.String)this.getValue(RES_AUTH);
	}

	// This attribute is optional
	public void setResSharingScope(java.lang.String value) {
		this.setValue(RES_SHARING_SCOPE, value);
	}

	//
	public java.lang.String getResSharingScope() {
		return (java.lang.String)this.getValue(RES_SHARING_SCOPE);
	}

	//
	public static void addComparator(org.netbeans.modules.schema2beans.BeanComparator c) {
		comparators.add(c);
	}

	//
	public static void removeComparator(org.netbeans.modules.schema2beans.BeanComparator c) {
		comparators.remove(c);
	}
	public void validate() throws org.netbeans.modules.schema2beans.ValidateException {
	}

	// Dump the content of this bean returning it as a String
	public void dump(StringBuffer str, String indent){
		String s;
		Object o;
		org.netbeans.modules.schema2beans.BaseBean n;
		str.append(indent);
		str.append("Description["+this.sizeDescription()+"]");	// NOI18N
		for(int i=0; i<this.sizeDescription(); i++)
		{
			str.append(indent+"\t");
			str.append("#"+i+":");
			str.append(indent+"\t");	// NOI18N
			str.append("<");	// NOI18N
			s = this.getDescription(i);
			str.append((s==null?"null":s.trim()));	// NOI18N
			str.append(">\n");	// NOI18N
			this.dumpAttributes(DESCRIPTION, i, str, indent);
		}

		str.append(indent);
		str.append("ResRefName");	// NOI18N
		str.append(indent+"\t");	// NOI18N
		str.append("<");	// NOI18N
		s = this.getResRefName();
		str.append((s==null?"null":s.trim()));	// NOI18N
		str.append(">\n");	// NOI18N
		this.dumpAttributes(RES_REF_NAME, 0, str, indent);

		str.append(indent);
		str.append("ResType");	// NOI18N
		str.append(indent+"\t");	// NOI18N
		str.append("<");	// NOI18N
		s = this.getResType();
		str.append((s==null?"null":s.trim()));	// NOI18N
		str.append(">\n");	// NOI18N
		this.dumpAttributes(RES_TYPE, 0, str, indent);

		str.append(indent);
		str.append("ResAuth");	// NOI18N
		str.append(indent+"\t");	// NOI18N
		str.append("<");	// NOI18N
		s = this.getResAuth();
		str.append((s==null?"null":s.trim()));	// NOI18N
		str.append(">\n");	// NOI18N
		this.dumpAttributes(RES_AUTH, 0, str, indent);

		str.append(indent);
		str.append("ResSharingScope");	// NOI18N
		str.append(indent+"\t");	// NOI18N
		str.append("<");	// NOI18N
		s = this.getResSharingScope();
		str.append((s==null?"null":s.trim()));	// NOI18N
		str.append(">\n");	// NOI18N
		this.dumpAttributes(RES_SHARING_SCOPE, 0, str, indent);

	}
	public String dumpBeanNode(){
		StringBuffer str = new StringBuffer();
		str.append("ResourceRefType\n");	// NOI18N
		this.dump(str, "\n  ");	// NOI18N
		return str.toString();
	}}

// END_NOI18N


/*
 * The contents of this file are subject to the terms 
 * of the Common Development and Distribution License 
 * (the License).  You may not use this file except in
 * compliance with the License.
 * 
 * You can obtain a copy of the license at 
 * https://glassfish.dev.java.net/public/CDDLv1.0.html or
 * glassfish/bootstrap/legal/CDDLv1.0.txt.
 * See the License for the specific language governing 
 * permissions and limitations under the License.
 * 
 * When distributing Covered Code, include this CDDL 
 * Header Notice in each file and include the License file 
 * at glassfish/bootstrap/legal/CDDLv1.0.txt.  
 * If applicable, add the following below the CDDL Header, 
 * with the fields enclosed by brackets [] replaced by
 * you own identifying information: 
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 */

==> glassfishv2_2.0.1.orig.tar.gz: glassfish/tools/src/java/com/sun/enterprise/tools/common/dd/webservice/ResourceRefType.java <==
/**
 *	This generated bean class ResourceRefType matches the schema element resource-refType
 *
 *	===============================================================
 *	
 *		
 *	
 *		  The resource-refType contains a declaration of a
 *		  Deployment Component's reference to an external resource. It
 *		  consists of an optional description, the resource manager
 *		  connection factory reference name, the indication of the
 *		  resource manager connection factory type expected by the
 *		  Deployment Component code, the type of authentication
 *		  (Application or Container), and an optional specification of
 *		  the shareability of connections obtained from the resource
 *		  (Shareable or Unshareable).
 *	
 *		  Example:
 *	
 *		  <resource-ref>
 *		      <res-ref-name>jdbc/EmployeeAppDB</res-ref-name>
 *		      <res-type>javax.sql.DataSource</res-type>
 *		      <res-auth>Container</res-auth>
 *		      <res-sharing-scope>Shareable</res-sharing-scope>
 *		  </resource-ref>
 *	
 *		  
 *	      
 *	===============================================================
 *	Generated on Fri Apr 22 15:42:51 PDT 2005
 */

package com.sun.enterprise.tools.common.dd.webservice;

import org.w3c.dom.*;
import org.netbeans.modules.schema2beans.*;
import java.beans.*;
import java.util.*;

// BEGIN_NOI18N

public class ResourceRefType extends org.netbeans.modules.schema2beans.BaseBean
{

	static Vector comparators = new Vector();

	static public final String DESCRIPTION = "Description";	// NOI18N
	static public final String RES_REF_NAME = "ResRefName";	// NOI18N
	static public final String RES_TYPE = "ResType";	// NOI18N
	static public final String RES_AUTH = "ResAuth";	// NOI18N
	static public final String RES_SHARING_SCOPE = "ResSharingScope";	// NOI18N

	public ResourceRefType() {
		this(Common.USE_DEFAULT_VALUES);
	}

	public ResourceRefType(int options)
	{
		super(comparators, new org.netbeans.modules.schema2beans.Version(1, 2, 0));
		// Properties (see root bean comments for the bean graph)
		this.createProperty("description", 	// NOI18N
			DESCRIPTION, 
			Common.TYPE_0_N | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.createAttribute(DESCRIPTION, "id", "Id", 
						AttrProp.CDATA | AttrProp.IMPLIED,
						null, null);
		this.createAttribute(DESCRIPTION, "xml:lang", "XmlLang", 
						AttrProp.CDATA | AttrProp.IMPLIED,
						null, null);
		this.createProperty("res-ref-name", 	// NOI18N
			RES_REF_NAME, 
			Common.TYPE_1 | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.createProperty("res-type", 	// NOI18N
			RES_TYPE, 
			Common.TYPE_1 | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.createProperty("res-auth", 	// NOI18N
			RES_AUTH, 
			Common.TYPE_1 | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.createProperty("res-sharing-scope", 	// NOI18N
			RES_SHARING_SCOPE, 
			Common.TYPE_0_1 | Common.TYPE_STRING | Common.TYPE_KEY, 
			java.lang.String.class);
		this.initialize(options);
	}

	// Setting the default values of the properties
	void initialize(int options)
	{

	}

	// This attribute is an array, possibly empty
	public void setDescription(int index, java.lang.String value) {
		this.setValue(DESCRIPTION, index, value);
	}

	//
	public java.lang.String getDescription(int index) {
		return (java.lang.String)this.getValue(DESCRIPTION, index);
	}

	// This attribute is an array, possibly empty
	public void setDescription(java.lang.String[] value) {
		this.setValue(DESCRIPTION, value);
	}

	//
	public java.lang.String[] getDescription() {
		return (java.lang.String[])this.getValues(DESCRIPTION);
	}

	// Return the number of properties
	public int sizeDescription() {
		return this.size(DESCRIPTION);
	}

	// Add a new element returning its index in the list
	public int addDescription(java.lang.String value) {
		return this.addValue(DESCRIPTION, value);
	}

	//
	// Remove an element using its reference
	// Returns the index the element had in the list
	//
	public int removeDescription(java.lang.String value) {
		return this.removeValue(DESCRIPTION, value);
	}

	// This attribute is mandatory
	public void setResRefName(java.lang.String value) {
		this.setValue(RES_REF_NAME, value);
	}

	//
	public java.lang.String getResRefName() {
		return (java.lang.String)this.getValue(RES_REF_NAME);
	}

	// This attribute is mandatory
	public void setResType(java.lang.String value) {
		this.setValue(RES_TYPE, value);
	}

	//
	public java.lang.String getResType() {
		return (java.lang.String)this.getValue(RES_TYPE);
	}

	// This attribute is mandatory
	public void setResAuth(java.lang.String value) {
		this.setValue(RES_AUTH, value);
	}

	//
	public java.lang.String getResAuth() {
		return (java.lang.String)this.getValue(RES_AUTH);
	}

	// This attribute is optional
	public void setResSharingScope(java.lang.String value) {
		this.setValue(RES_SHARING_SCOPE, value);
	}

	//
	public java.lang.String getResSharingScope() {
		return (java.lang.String)this.getValue(RES_SHARING_SCOPE);
	}

	//
	public static void addComparator(org.netbeans.modules.schema2beans.BeanComparator c) {
		comparators.add(c);
	}

	//
	public static void removeComparator(org.netbeans.modules.schema2beans.BeanComparator c) {
		comparators.remove(c);
	}
	public void validate() throws org.netbeans.modules.schema2beans.ValidateException {
	}

	// Dump the content of this bean returning it as a String
	public void dump(StringBuffer str, String indent){
		String s;
		Object o;
		org.netbeans.modules.schema2beans.BaseBean n;
		str.append(indent);
		str.append("Description["+this.sizeDescription()+"]");	// NOI18N
		for(int i=0; i<this.sizeDescription(); i++)
		{
			str.append(indent+"\t");
			str.append("#"+i+":");
			str.append(indent+"\t");	// NOI18N
			str.append("<");	// NOI18N
			s = this.getDescription(i);
			str.append((s==null?"null":s.trim()));	// NOI18N
			str.append(">\n");	// NOI18N
			this.dumpAttributes(DESCRIPTION, i, str, indent);
		}

		str.append(indent);
		str.append("ResRefName");	// NOI18N
		str.append(indent+"\t");	// NOI18N
		str.append("<");	// NOI18N
		s = this.getResRefName();
		str.append((s==null?"null":s.trim()));	// NOI18N
		str.append(">\n");	// NOI18N
		this.dumpAttributes(RES_REF_NAME, 0, str, indent);

		str.append(indent);
		str.append("ResType");	// NOI18N
		str.append(indent+"\t");	// NOI18N
		str.append("<");	// NOI18N
		s = this.getResType();
		str.append((s==null?"null":s.trim()));	// NOI18N
		str.append(">\n");	// NOI18N
		this.dumpAttributes(RES_TYPE, 0, str, indent);

		str.append(indent);
		str.append("ResAuth");	// NOI18N
		str.append(indent+"\t");	// NOI18N
		str.append("<");	// NOI18N
		s = this.getResAuth();
		str.append((s==null?"null":s.trim()));	// NOI18N
		str.append(">\n");	// NOI18N
		this.dumpAttributes(RES_AUTH, 0, str, indent);

		str.append(indent);
		str.append("ResSharingScope");	// NOI18N
		str.append(indent+"\t");	// NOI18N
		str.append("<");	// NOI18N
		s = this.getResSharingScope();
		str.append((s==null?"null":s.trim()));	// NOI18N
		str.append(">\n");	// NOI18N
		this.dumpAttributes(RES_SHARING_SCOPE, 0, str, indent);

	}
	public String dumpBeanNode(){
		StringBuffer str = new StringBuffer();
		str.append("ResourceRefType\n");	// NOI18N
		this.dump(str, "\n  ");	// NOI18N
		return str.toString();
	}}

// END_NOI18N


/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
